@@ -1,5 +1,7 @@
 from robotdatapy import camera
 from robotdatapy import data
+from robotdatapy import data_fusion
+from robotdatapy import exceptions
 from robotdatapy import geometry
 from robotdatapy import ros_msg_convert
 from robotdatapy import transform
\ No newline at end of file
