@@ -853,31 +853,4 @@ class PoseData(RobotData):
                                                  transform_msg.transform.rotation.y, 
                                                  transform_msg.transform.rotation.z, 
                                                  transform_msg.transform.rotation.w])
-        return cls(times, positions, orientations, **kwargs)
-    
-    def _get_time_array(self, t: List[float], dt: float, t0: float, tf: float) -> np.ndarray:
-        """
-        Given some timing options, a numpy array of times (e.g., used for plotting) are returned
-
-        Args:
-            t (List[float]): If a list of floats (times) are provided, this will just be returned
-                as is.
-            dt (float): If t is not provided (is None) then an array from t0 to tf with spacing dt
-                is returned.
-            t0 (float): If t is not provided (is None) then an array from t0 to tf with spacing dt
-                is returned.
-            tf (float): If t is not provided (is None) then an array from t0 to tf with spacing dt
-                is returned.
-
-        Returns:
-            np.ndarray: List of times
-        """
-        if t0 is None and t is None:
-            t0 = self.t0
-        if tf is None and t is None:
-            tf = self.tf
-            
-        if t is not None:
-            return t
-        else:
-            return np.arange(t0, tf, dt)
\ No newline at end of file
+        return cls(times, positions, orientations, **kwargs)
\ No newline at end of file
